.. image:: https://img.shields.io/pypi/v/jaraco.util.svg
   :target: https://pypi.org/project/jaraco.util

.. image:: https://img.shields.io/pypi/pyversions/jaraco.util.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.util/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.util

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/jaraco.util/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/jaraco.util/branch/master

.. .. image:: https://readthedocs.org/projects/jaracoutil/badge/?version=latest
..    :target: https://jaracoutil.readthedocs.io/en/latest/?badge=latest

``jaraco.util`` contains a number of nominally useful, reusable classes
and functions. Each is designed to be intuitively named and
self-documenting (many with extensive doctests), though
the project is also documented with runnable tests.

Deprecation
-----------

In general, this grab-bag of routines is deprecated, with much of the
functionality moved or pending move to another, more appropriate home.
